================================
 Vitrage-Dashboard Release Notes
================================

Contents
========

.. toctree::
   :maxdepth: 2

   unreleased
   queens
   pike
   ocata


Indices and tables
==================

* :ref:`genindex`
* :ref:`search`
